@section('title', 'Sejarah')

@extends('Frontend.Layouts.app2')
@section('content')
<br><br>
    <x-header-section-page title="Sejarah  {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}" breadcrumb-home="Home" breadcrumb-current="Sejarah Singkat" />

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        {{-- <img src="{{ asset('./images/sambutan/petinggi.png') }}" data-aos="fade-up" class=" mb-5 w-full" alt=""> --}}

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p class="text-justify" style="font-size: 14px;">
                Sekolah Tinggi Ilmu Ekonomi (STIE) Ganesha berdiri pada tanggal 11 September 1993, dengan nomor SK izin operasional: 131/D/O/1993 dan terakreditasi BAN PT untuk Program Studi Magister Manajemen dan nomor SK Izin operasional: 373/DIKTI/KEP/2000 tanggal 20 Oktober 2000 dan terakreditasi BAN PT untuk Program Studi S1 Manajemen dan S1 Akutansi. <br>
                
                Sejalan mengikuti pesatnya perkembangan jaman dan persaingan global sebagai suatu kenyataan yang tak mungkin bisa dihindari. Membawa dampak pada persiapan tersedianya sumber daya manusia yang handal, profesional dan excellent.Sekaligus sebagai konsekuensi lembaga pendidikan tinggi harus mampu mencetak tenaga ahli sebagai sumber daya manusia yang memiliki pengetahuan secara akademik serta mampu dalam mempresentasikan masalah secara ilmiah pula, antara lain menguasai peralatan analisis serta berfikir logis, kritis, sistimatis dan analitis, mempunyai pengetahuan konsepsional untuk mengidentifikasi dan merumuskan masalah yang dihadapi serta mampu menawarkan alternatif pemecahan.<br>
                
                Maka sebagai wujud latar belakang dimaksud, Sekolah Tinggi Ilmu ekonomi Ganesha dalam poengelolaan pendidikan mempersiapkan tenaga pengajar profesional serta para birokrat yang berpengalaman pada bidangnya dan memiliki kepangkatan lektor sampai guru besar melalui SK Dirjen Dikti.<br>
                
            </p>

        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
                </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
            Bergabunglah bersama  {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }} dan Bangun Wawasan, Bentuk Karakter, Jadilah Pembawa Perubahan!
        </p>
            <x-button url="/pendaftaran">DAFTAR SEKARANG</x-button>
        </div>
    </div>
@endsection
